searchData={"items":[{"type":"module","title":"CozyTelemetry","doc":"Provides a modular approach for using [beam-telemetry](https://github.com/beam-telemetry) packages.","ref":"CozyTelemetry.html"},{"type":"module","title":"Quick Start - CozyTelemetry","doc":"Before running `CozyTelemetry`, you must provide some modules. For example:\n\n    defmodule MyApp.Cache.TelemetrySpec do\n      use CozyTelemetry.Spec\n\n      @impl true\n      def metrics(_meta) do\n        [\n          summary(\"cache.duration\",\n            unit: {:native, :second},\n            tags: [:type, :key]\n          ),\n\n          last_value(\"cache.stats.hits\",\n            event_name: \"cache.stats\",\n            measurement: :hits,\n            tags: [:cache]\n          )\n        ]\n      end\n\n      @impl true\n      def measurements(meta) do\n        [\n          {__MODULE__, :dispatch_stats, []}\n        ]\n      end\n    end\n\nThen, set some base configuration within `config/config.exs`:\n\n    config :my_app, CozyTelemetry,\n      meta: [],\n      specs: [\n        MyApp.Cache.TelemetrySpec\n      ],\n      reporter: {:console, []},\n      poller: [period: 10_000]\n\nUse the application configuration you've already set and include `CozyTelemetry.*` in the list of\nsupervised children:\n\n    # lib/my_app/application.ex\n    def start(_type, _args) do\n      cozy_telemetry_config = Application.fetch_env!(:my_app, CozyTelemetry)\n\n      children = [\n        {CozyTelemetry.Reporter, cozy_telemetry_config},\n        {CozyTelemetry.Poller, cozy_telemetry_config},\n        # ...\n      ]\n\n      Supervisor.start_link(children, strategy: :one_for_one, name: MyApp.Supervisor)\n    end\n\n#","ref":"CozyTelemetry.html#module-quick-start"},{"type":"module","title":"about option `:meta` - CozyTelemetry","doc":"The value of option `:meta` is a keyword list, which will be passed as the argument of:\n\n+ callback `metrics/1` of `CozyTelemetry.Spec`.\n+ callback `measurements/1` of `CozyTelemetry.Spec`.\n\nSee `CozyTelemetry.Spec` for more details.\n\n#","ref":"CozyTelemetry.html#module-about-option-meta"},{"type":"module","title":"about option `:specs` - CozyTelemetry","doc":"The value of option `:specs` is a list of spec modules.\n\nSee `CozyTelemetry.Spec` for more details.\n\n#","ref":"CozyTelemetry.html#module-about-option-specs"},{"type":"module","title":"about option `:optional_specs` - CozyTelemetry","doc":"Same as option `:specs`, but ignore errors when the given spec module is missing.\n\n> When using `:cozy_telemetry` as a direct dependency, this option is unnecessary.\n> But, when building a new package on `:cozy_telemetry`, this option is useful for some case,\n> such as auto loading measurements modules.\n\n#","ref":"CozyTelemetry.html#module-about-option-optional_specs"},{"type":"module","title":"about option `:reporter` - CozyTelemetry","doc":"The value of option `:reporter` specifies the reporter and its options, which is in format of\n`{type, reporter_opts}`:\n\n+ available values of `type` are `:console`, `:statsd`, `prometheus`.\n+ available values of `reporter_opts` can be found in corresponding underlying modules:\n  - `Telemetry.Metrics.ConsoleReporter`\n  - [`TelemetryMetricsStatsd`](https://hexdocs.pm/telemetry_metrics_statsd)\n  - [`TelemetryMetricsPrometheus`](https://hexdocs.pm/telemetry_metrics_prometheus)\n\n#","ref":"CozyTelemetry.html#module-about-option-reporter"},{"type":"module","title":"about option `:poller` - CozyTelemetry","doc":"The value of option `:poller` is the options of `:telemetry_poller.start_link/1`.","ref":"CozyTelemetry.html#module-about-option-poller"},{"type":"function","title":"CozyTelemetry.load_measurements/1","doc":"","ref":"CozyTelemetry.html#load_measurements/1"},{"type":"function","title":"CozyTelemetry.load_metrics/1","doc":"","ref":"CozyTelemetry.html#load_metrics/1"},{"type":"module","title":"CozyTelemetry.Poller","doc":"The application that fetches measurements periodically.","ref":"CozyTelemetry.Poller.html"},{"type":"function","title":"CozyTelemetry.Poller.child_spec/1","doc":"Builds a child specifications.","ref":"CozyTelemetry.Poller.html#child_spec/1"},{"type":"behaviour","title":"CozyTelemetry.Reporter","doc":"The application which reports metrics.\n\nThis module also defines a behaviour for declaring reporters.","ref":"CozyTelemetry.Reporter.html"},{"type":"callback","title":"CozyTelemetry.Reporter.check_deps/0","doc":"Checks required dependencies.\n\nWhen dependencies are missing, an exception should be raised.","ref":"CozyTelemetry.Reporter.html#c:check_deps/0"},{"type":"function","title":"CozyTelemetry.Reporter.child_spec/1","doc":"Builds a child specifications.","ref":"CozyTelemetry.Reporter.html#child_spec/1"},{"type":"callback","title":"CozyTelemetry.Reporter.child_spec/1","doc":"Generates child specification for starting a reporter.","ref":"CozyTelemetry.Reporter.html#c:child_spec/1"},{"type":"type","title":"CozyTelemetry.Reporter.child_spec/0","doc":"","ref":"CozyTelemetry.Reporter.html#t:child_spec/0"},{"type":"type","title":"CozyTelemetry.Reporter.init_arg/0","doc":"","ref":"CozyTelemetry.Reporter.html#t:init_arg/0"},{"type":"behaviour","title":"CozyTelemetry.Spec","doc":"A behaviour for declaring spec.\n\nAny module that wants to exposing metrics or periodic measurements should\nimplement this behaviour.\n\n    defmodule MyApp.Cache.TelemetrySpec do\n      use CozyTelemetry.Spec\n\n      @impl true\n      def metrics(meta) do\n        [\n          summary(\"cache.duration\",\n            unit: {:native, :second},\n            tags: [:type, :key]\n          ),\n          # ...\n        ]\n      end\n\n      @impl true\n      def measurements(meta) do\n        [\n          {__MODULE__, :dispatch_stats, []},\n          # ...\n        ]\n      end\n    end\n\nThen, the declared metrics in above module can be loaded with following configuration:\n\n    config :my_app, CozyTelemetry,\n      meta: [],\n      specs: [\n        MyApp.Cache.TelemetrySpec\n      ],\n      # ...","ref":"CozyTelemetry.Spec.html"},{"type":"function","title":"CozyTelemetry.Spec.load_measurements/1","doc":"Load measurements.","ref":"CozyTelemetry.Spec.html#load_measurements/1"},{"type":"function","title":"CozyTelemetry.Spec.load_measurements_from_module/2","doc":"Loads the measurements from given module.","ref":"CozyTelemetry.Spec.html#load_measurements_from_module/2"},{"type":"function","title":"CozyTelemetry.Spec.load_measurements_from_module!/2","doc":"Same as `load_measurements_from_module/2` but raises if the module cannot be loaded.","ref":"CozyTelemetry.Spec.html#load_measurements_from_module!/2"},{"type":"function","title":"CozyTelemetry.Spec.load_metrics/1","doc":"Load metrics.","ref":"CozyTelemetry.Spec.html#load_metrics/1"},{"type":"function","title":"CozyTelemetry.Spec.load_metrics_from_module/2","doc":"Loads the metrics from given module.","ref":"CozyTelemetry.Spec.html#load_metrics_from_module/2"},{"type":"function","title":"CozyTelemetry.Spec.load_metrics_from_module!/2","doc":"Same as `load_metrics_from_module/2` but raises if the module cannot be loaded.","ref":"CozyTelemetry.Spec.html#load_metrics_from_module!/2"},{"type":"callback","title":"CozyTelemetry.Spec.measurements/1","doc":"Declares measurements.","ref":"CozyTelemetry.Spec.html#c:measurements/1"},{"type":"callback","title":"CozyTelemetry.Spec.metrics/1","doc":"Declares metrics.","ref":"CozyTelemetry.Spec.html#c:metrics/1"},{"type":"type","title":"CozyTelemetry.Spec.meta/0","doc":"","ref":"CozyTelemetry.Spec.html#t:meta/0"},{"type":"extras","title":"CozyTelemetry","doc":"# CozyTelemetry\n\n[![CI](https://github.com/cozy-elixir/cozy_telemetry/actions/workflows/ci.yml/badge.svg)](https://github.com/cozy-elixir/cozy_telemetry/actions/workflows/ci.yml)\n[![Hex.pm](https://img.shields.io/hexpm/v/cozy_telemetry.svg)](https://hex.pm/packages/cozy_telemetry)\n[![built with Nix](https://img.shields.io/badge/built%20with%20Nix-5277C3?logo=nixos&logoColor=white)](https://builtwithnix.org)\n\n> Provides a modular approach for using [beam-telemetry](https://github.com/beam-telemetry) packages.","ref":"readme.html"},{"type":"extras","title":"Notes - CozyTelemetry","doc":"This package is still in its early stages, so it may still undergo significant changes, potentially leading to breaking changes.","ref":"readme.html#notes"},{"type":"extras","title":"Installation - CozyTelemetry","doc":"Add `:cozy_telemetry` to the list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:cozy_telemetry, \" \"}\n  ]\nend\n```\n\n> **Note**\n>\n> `:cozy_telemetry` is depending on following packages:\n>\n> - `:telemetry`\n> - `:telemetry_poller`\n> - `:telemetry_metrics`\n>\n> If you want to use them, there is no need to add them to `mix.exs` explicitly. They are available after you adding `:cozy_telemetry`.","ref":"readme.html#installation"},{"type":"extras","title":"Usage - CozyTelemetry","doc":"For more information, see the [documentation](https://hexdocs.pm/cozy_telemetry/CozyTelemetry.html).","ref":"readme.html#usage"},{"type":"extras","title":"License - CozyTelemetry","doc":"Apache License 2.0","ref":"readme.html#license"},{"type":"extras","title":"Changelog","doc":"# Changelog","ref":"changelog.html"},{"type":"extras","title":"v0.5.0 - Changelog","doc":"Breaking changes:\n\n- `CozyTelemetry.Metrics` and `CozyTelemetry.Measurements` are merged as `CozyTelemetry.Spec`.\n- `:metrics` option and `:measurements` option are merged as `:specs`.\n- `:optional_metrics` option and `:optional_measurements` option are merged as `:optional_specs`.","ref":"changelog.html#v0-5-0"}],"content_type":"text/markdown"}